summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--weblog-model.lua8
1 files changed, 7 insertions, 1 deletions
diff --git a/weblog-model.lua b/weblog-model.lua
index 7f09c7d..faac6a7 100644
--- a/weblog-model.lua
+++ b/weblog-model.lua
@@ -514,6 +514,12 @@ local function checkwords(logentry)
end
end
+ --check for Squark category
+ if (logentry.squarkcategory and logentry.squarkcategory ~= "") then
+ logentry.reason = logentry.squarkcategory
+ logentry.shortreason = logentry.squarkcategory
+ end
+
for i,goodline in ipairs(goodwords) do
if not goodline then
break
@@ -543,7 +549,7 @@ end
local function parsesquidlog(line)
-- Format of squid log (space separated):
- -- time elapsed remotehost code/status bytes method URL rfc931 peerstatus/peerhost
+ -- time elapsed remotehost code/status bytes method URL rfc931 peerstatus/peerhost ? squarkcategory/squarkaction
local words = {}
for word in string.gmatch(line, "%S+") do